@@ -5,14 +5,15 @@
 package Data::Dump::Color;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-13'; # DATE
+our $DATE = '2021-06-04'; # DATE
 our $DIST = 'Data-Dump-Color'; # DIST
-our $VERSION = '0.243'; # VERSION
+our $VERSION = '0.244'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
-use vars qw(@EXPORT @EXPORT_OK $VERSION $DEBUG);
 use subs qq(dump);
+use vars qw(@EXPORT @EXPORT_OK $VERSION $DEBUG);
+use warnings;
 
 require Exporter;
 *import = \&Exporter::import;
@@ -54,7 +55,7 @@ sub _col {
     return $str unless $COLOR;
 
     my $ansi = '';
-    my $item = $ct_obj->get_item_color($item);
+    $item = $ct_obj->get_item_color($item);
     if (defined $item) {
         $ansi = ColorThemeUtil::ANSI::item_color_to_ansi($item);
     }
@@ -765,7 +766,7 @@ Data::Dump::Color - Like Data::Dump, but with color
 
 =head1 VERSION
 
-This document describes version 0.243 of Data::Dump::Color (from Perl distribution Data-Dump-Color), released on 2021-02-13.
+This document describes version 0.244 of Data::Dump::Color (from Perl distribution Data-Dump-Color), released on 2021-06-04.
 
 =head1 SYNOPSIS
 
@@ -933,6 +934,22 @@ L<Data::Dump>, L<JSON::Color>, L<YAML::Tiny::Color>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Scott Baker Steven Haryanto
+
+=over 4
+
+=item *
+
+Scott Baker <bakerscot@cpan.org>
+
+=item *
+
+Steven Haryanto <sharyanto@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2021, 2018, 2014, 2013, 2012 by perlancar@cpan.org.
